@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 ## src/common/gajim.py
 ##
-## Copyright (C) 2003-2010 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2003-2012 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
 ##                         Travis Shirk <travis AT pobox.com>
 ##                         Nikos Kouremenos <kourem AT gmail.com>
@@ -33,32 +33,8 @@ import locale
 
 import config
 import xmpp
-
-try:
-    import defs
-except ImportError:
-    print >> sys.stderr, '''defs.py is missing!
-
-If you start gajim from svn:
-* Make sure you have GNU autotools installed.
-This includes the following packages:
-automake >= 1.8
-autoconf >= 2.59
-intltool-0.35
-libtool
-* Run
-$ sh autogen.sh
-* Optionally, install gajim
-$ make
-$ sudo make install
-
-**** Note for translators ****
-You can get the latest string updates, by running:
-$ cd po/
-$ make update-po
-
-'''
-    sys.exit(1)
+import defs
+import common.ged
 
 interface = None # The actual interface (the gtk one for the moment)
 thread_interface = None # Interface to run a thread and then a callback
@@ -67,7 +43,9 @@ version = config.get('version')
 connections = {} # 'account name': 'account (connection.Connection) instance'
 ipython_window = None
 
-ged = None # Global Events Dispatcher
+ged = common.ged.GlobalEventsDispatcher() # Global Events Dispatcher
+nec = None # Network Events Controller
+plugin_manager = None # Plugins Manager
 
 log = logging.getLogger('gajim')
 
@@ -88,6 +66,9 @@ TMP = gajimpaths['TMP']
 DATA_DIR = gajimpaths['DATA']
 ICONS_DIR = gajimpaths['ICONS']
 HOME_DIR = gajimpaths['HOME']
+PLUGINS_DIRS = [gajimpaths['PLUGINS_BASE'],
+                gajimpaths['PLUGINS_USER']]
+PLUGINS_CONFIG_DIR = gajimpaths['PLUGINS_CONFIG_DIR']
 
 try:
     LANG = locale.getdefaultlocale()[0] # en_US, fr_FR, el_GR etc..
@@ -124,6 +105,8 @@ to_be_removed = {} # list of contacts that has just signed out
 
 events = Events()
 
+notification = None
+
 nicks = {} # list of our nick names in each account
 # should we block 'contact signed in' notifications for this account?
 # this is only for the first 30 seconds after we change our show
@@ -154,38 +137,68 @@ ZEROCONF_ACC_NAME = 'Local'
 
 HAVE_ZEROCONF = True
 try:
-    import avahi
+    __import__('avahi')
 except ImportError:
     try:
-        import pybonjour
+        __import__('pybonjour')
     except Exception: # Linux raises ImportError, Windows raises WindowsError
         HAVE_ZEROCONF = False
 
 HAVE_PYCRYPTO = True
 try:
-    import Crypto
+    __import__('Crypto')
 except ImportError:
     HAVE_PYCRYPTO = False
 
 HAVE_GPG = True
 try:
-    import GnuPGInterface
+    __import__('gnupg', globals(), locals(), [], -1)
 except ImportError:
     HAVE_GPG = False
 else:
-    from os import system
-    if system('gpg -h >/dev/null 2>&1'):
+    import os
+    import subprocess
+    if os.name == 'nt':
+        gpg_cmd = 'gpg -h >nul 2>&1'
+    else:
+        gpg_cmd = 'gpg -h >/dev/null 2>&1'
+    if subprocess.call(gpg_cmd, shell=True):
         HAVE_GPG = False
 
 # Depends on use_latex option. Will be correctly set after we config options are
 # read.
 HAVE_LATEX = False
 
-HAVE_FARSIGHT = True
+HAVE_FARSTREAM = True
 try:
-    import farsight, gst
+    farstream = __import__('farstream')
+    import gst
+    import glib
+    try:
+        conference = gst.element_factory_make('fsrtpconference')
+        session = conference.new_session(farstream.MEDIA_TYPE_AUDIO)
+        del session
+        del conference
+    except glib.GError:
+        HAVE_FARSTREAM = False
+
 except ImportError:
-    HAVE_FARSIGHT = False
+    HAVE_FARSTREAM = False
+
+HAVE_UPNP_IGD = True
+try:
+    import gupnp.igd
+    gupnp_igd = gupnp.igd.Simple()
+except ImportError:
+    HAVE_UPNP_IGD = False
+
+HAVE_PYCURL = True
+try:
+    __import__('pycurl')
+except ImportError:
+    HAVE_PYCURL = False
+
+
 gajim_identity = {'type': 'pc', 'category': 'client', 'name': 'Gajim'}
 gajim_common_features = [xmpp.NS_BYTESTREAM, xmpp.NS_SI, xmpp.NS_FILE,
         xmpp.NS_MUC, xmpp.NS_MUC_USER, xmpp.NS_MUC_ADMIN, xmpp.NS_MUC_OWNER,
