@@ -60,6 +60,7 @@ class NonBlockingClient:
         self._owner = self
         self._registered_name = None # our full jid, set after successful auth
         self.connected = ''
+        self.ip_addresses = []
         self.socket = None
         self.on_connect = None
         self.on_proxy_failure = None
@@ -76,6 +77,9 @@ class NonBlockingClient:
         the client.
         """
         # to avoid recursive calls
+        if self.ip_addresses:
+            self._try_next_ip()
+            return
         if self.disconnecting: return
 
         log.info('Disconnecting NBClient: %s' % message)
@@ -317,6 +321,7 @@ class NonBlockingClient:
         elif mode == 'RECEIVE_DOCUMENT_ATTRIBUTES':
             if data:
                 self.Dispatcher.ProcessNonBlocking(data)
+                self.ip_addresses = []
             if not hasattr(self, 'Dispatcher') or \
                     self.Dispatcher.Stream._document_attrs is None:
                 self._xmpp_connect_machine(
@@ -488,6 +493,8 @@ class NonBlockingClient:
         if self._sasl:
             auth_nb.SASL.get_instance(self._User, self._Password,
                     self._on_start_sasl).PlugIn(self)
+        if not hasattr(self, 'SASL'):
+            return
         if not self._sasl or self.SASL.startsasl == 'not-supported':
             if not self._Resource:
                 self._Resource = 'xmpppy'
@@ -516,7 +523,17 @@ class NonBlockingClient:
             self.connected = None # FIXME: is this intended? We use ''elsewhere
             self._on_sasl_auth(None)
         elif self.SASL.startsasl == 'success':
-            auth_nb.NonBlockingBind.get_instance().PlugIn(self)
+            nb_bind = auth_nb.NonBlockingBind.get_instance()
+            sm = self._caller.sm
+            if  sm._owner and sm.resumption:
+                nb_bind.resuming = True
+                sm.set_owner(self)
+                self.Dispatcher.sm = sm
+                nb_bind.PlugIn(self)
+                self.on_auth(self, 'sasl')
+                return
+
+            nb_bind.PlugIn(self)
             self.onreceive(self._on_auth_bind)
         return True
 
