@@ -5,7 +5,7 @@
 ## Copyright (C) 2005-2006 Alex Mauer <hawke AT hawkesnest.net>
 ##                         Travis Shirk <travis AT pobox.com>
 ## Copyright (C) 2005-2007 Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2010 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2005-2012 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
 ## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
 ## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
@@ -915,15 +915,19 @@ class ConversationTextview(gobject.GObject):
                     self.on_join_group_chat_menuitem_activate, text)
             self.handlers[id_] = childs[6]
 
-            if self.account:
-                id_ = childs[7].connect('activate', self.on_add_to_roster_activate,
-                        text)
+            if self.account and gajim.connections[self.account].\
+            roster_supported:
+                id_ = childs[7].connect('activate',
+                    self.on_add_to_roster_activate, text)
                 self.handlers[id_] = childs[7]
                 childs[7].show() # show add to roster menuitem
             else:
                 childs[7].hide() # hide add to roster menuitem
 
             if kind == 'xmpp':
+                id_ = childs[0].connect('activate', self.on_copy_link_activate,
+                    'xmpp:' + text)
+                self.handlers[id_] = childs[0]
                 childs[2].hide() # copy mail address
                 childs[3].hide() # open mail composer
                 childs[4].hide() # jid section separator
@@ -933,7 +937,8 @@ class ConversationTextview(gobject.GObject):
                 childs[6].hide() # join group chat
                 childs[7].hide() # add to roster
 
-            childs[0].hide() # copy link location
+            if kind != 'xmpp':
+                childs[0].hide() # copy link location
             childs[1].hide() # open link in browser
 
         menu.popup(None, None, None, event.button, event.time)
@@ -1038,6 +1043,15 @@ class ConversationTextview(gobject.GObject):
         Is called by detect_and_print_special_text and prints special text
         (emots, links, formatting)
         """
+
+
+        # PluginSystem: adding GUI extension point for ConversationTextview
+        self.plugin_modified = False
+        gajim.plugin_manager.gui_extension_point('print_special_text', self,
+            special_text, other_tags, graphics)
+        if self.plugin_modified:
+            return
+
         tags = []
         use_other_tags = True
         text_is_valid_uri = False
@@ -1296,7 +1310,7 @@ class ConversationTextview(gobject.GObject):
         Get the time, with the day before if needed and return it. It DOESN'T
         format a fuzzy time
         """
-        format = ''
+        format_ = ''
         # get difference in days since epoch (86400 = 24*3600)
         # number of days since epoch for current time (in GMT) -
         # number of days since epoch for message (in GMT)
@@ -1306,14 +1320,15 @@ class ConversationTextview(gobject.GObject):
             day_str = ''
         else:
             #%i is day in year (1-365)
-            day_str = i18n.ngettext('Yesterday', '%(nb_days)i days ago',
-                diff_day, {'nb_days': diff_day}, {'nb_days': diff_day})
+            day_str = i18n.ngettext('Yesterday',
+                '%(nb_days)i days ago', diff_day, {'nb_days': diff_day},
+                {'nb_days': diff_day})
         if day_str:
-            format += day_str + ' '
+            format_ += day_str + ' '
         timestamp_str = gajim.config.get('time_stamp')
         timestamp_str = helpers.from_one_line(timestamp_str)
-        format += timestamp_str
-        tim_format = time.strftime(format, tim)
+        format_ += timestamp_str
+        tim_format = time.strftime(format_, tim)
         if locale.getpreferredencoding() != 'KOI8-R':
             # if tim_format comes as unicode because of day_str.
             # we convert it to the encoding that we want (and that is utf-8)
