@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 ## src/filetransfers_window.py
 ##
-## Copyright (C) 2003-2010 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2003-2012 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
 ## Copyright (C) 2005-2007 Nikos Kouremenos <kourem AT gmail.com>
 ## Copyright (C) 2006 Travis Shirk <travis AT pobox.com>
@@ -175,7 +175,8 @@ class FileTransfersWindow:
             (file_path, file_name) = os.path.split(file_props['file-name'])
         else:
             file_name = file_props['name']
-        sectext = '\t' + _('Filename: %s') % file_name
+        sectext = '\t' + _('Filename: %s') % gobject.markup_escape_text(
+            file_name)
         sectext += '\n\t' + _('Size: %s') % \
         helpers.convert_bytes(file_props['size'])
         if file_props['type'] == 'r':
@@ -231,7 +232,8 @@ class FileTransfersWindow:
             file_name = os.path.basename(file_props['file-name'])
         else:
             file_name = file_props['name']
-        sectext = '\t' + _('Filename: %s') % file_name
+        sectext = '\t' + _('Filename: %s') % gobject.markup_escape_text(
+            file_name)
         sectext += '\n\t' + _('Recipient: %s') % jid
         if error_msg:
             sectext += '\n\t' + _('Error message: %s') % error_msg
@@ -239,16 +241,25 @@ class FileTransfersWindow:
         self.tree.get_selection().unselect_all()
 
     def show_file_send_request(self, account, contact):
-        desc_entry = gtk.Entry()
+        win = gtk.ScrolledWindow()
+        win.set_shadow_type(gtk.SHADOW_IN)
+        win.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
+
+        from message_textview import MessageTextView
+        desc_entry = MessageTextView()
+        win.add(desc_entry)
 
         def on_ok(widget):
             file_dir = None
             files_path_list = dialog.get_filenames()
             files_path_list = gtkgui_helpers.decode_filechooser_file_paths(
                     files_path_list)
-            desc = desc_entry.get_text()
+            text_buffer = desc_entry.get_buffer()
+            desc = text_buffer.get_text(text_buffer.get_start_iter(),
+                text_buffer.get_end_iter())
             for file_path in files_path_list:
-                if self.send_file(account, contact, file_path, desc) and file_dir is None:
+                if self.send_file(account, contact, file_path, desc) \
+                and file_dir is None:
                     file_dir = os.path.dirname(file_path)
             if file_dir:
                 gajim.config.set('last_send_dir', file_dir)
@@ -271,7 +282,7 @@ class FileTransfersWindow:
 
         desc_hbox = gtk.HBox(False, 5)
         desc_hbox.pack_start(gtk.Label(_('Description: ')), False, False, 0)
-        desc_hbox.pack_start(desc_entry, True, True, 0)
+        desc_hbox.pack_start(win, True, True, 0)
 
         dialog.vbox.pack_start(desc_hbox, False, False, 0)
 
@@ -292,7 +303,8 @@ class FileTransfersWindow:
             if contact.find('/') == -1:
                 return
             (jid, resource) = contact.split('/', 1)
-            contact = gajim.contacts.create_contact(jid=jid, account=account, resource=resource)
+            contact = gajim.contacts.create_contact(jid=jid, account=account,
+                resource=resource)
         file_name = os.path.split(file_path)[1]
         file_props = self.get_send_file_props(account, contact,
                         file_path, file_name, file_desc)
@@ -310,6 +322,71 @@ class FileTransfersWindow:
         self.add_transfer(account, contact, file_props)
         gajim.connections[account].send_file_approval(file_props)
 
+    def on_file_request_accepted(self, account, contact, file_props):
+        def on_ok(widget, account, contact, file_props):
+            file_path = dialog2.get_filename()
+            file_path = gtkgui_helpers.decode_filechooser_file_paths(
+                (file_path,))[0]
+            if os.path.exists(file_path):
+                # check if we have write permissions
+                if not os.access(file_path, os.W_OK):
+                    file_name = gobject.markup_escape_text(os.path.basename(
+                        file_path))
+                    dialogs.ErrorDialog(
+                        _('Cannot overwrite existing file "%s"' % file_name),
+                        _('A file with this name already exists and you do not '
+                        'have permission to overwrite it.'))
+                    return
+                stat = os.stat(file_path)
+                dl_size = stat.st_size
+                file_size = file_props['size']
+                dl_finished = dl_size >= file_size
+
+                def on_response(response):
+                    if response < 0:
+                        return
+                    elif response == 100:
+                        file_props['offset'] = dl_size
+                    dialog2.destroy()
+                    self._start_receive(file_path, account, contact, file_props)
+
+                dialog = dialogs.FTOverwriteConfirmationDialog(
+                    _('This file already exists'), _('What do you want to do?'),
+                    propose_resume=not dl_finished, on_response=on_response)
+                dialog.set_transient_for(dialog2)
+                dialog.set_destroy_with_parent(True)
+                return
+            else:
+                dirname = os.path.dirname(file_path)
+                if not os.access(dirname, os.W_OK) and os.name != 'nt':
+                    # read-only bit is used to mark special folder under
+                    # windows, not to mark that a folder is read-only.
+                    # See ticket #3587
+                    dialogs.ErrorDialog(_('Directory "%s" is not writable') % \
+                        dirname, _('You do not have permission to create files '
+                        'in this directory.'))
+                    return
+            dialog2.destroy()
+            self._start_receive(file_path, account, contact, file_props)
+
+        def on_cancel(widget, account, contact, file_props):
+            dialog2.destroy()
+            gajim.connections[account].send_file_rejection(file_props)
+
+        dialog2 = dialogs.FileChooserDialog(
+            title_text=_('Save File as...'),
+            action=gtk.FILE_CHOOSER_ACTION_SAVE,
+            buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+            gtk.STOCK_SAVE, gtk.RESPONSE_OK),
+            default_response=gtk.RESPONSE_OK,
+            current_folder=gajim.config.get('last_save_dir'),
+            on_response_ok=(on_ok, account, contact, file_props),
+            on_response_cancel=(on_cancel, account, contact, file_props))
+
+        dialog2.set_current_name(file_props['name'])
+        dialog2.connect('delete-event', lambda widget, event:
+            on_cancel(widget, account, contact, file_props))
+
     def show_file_request(self, account, contact, file_props):
         """
         Show dialog asking for comfirmation and store location of new file
@@ -330,64 +407,7 @@ class FileTransfersWindow:
         dialog = None
 
         def on_response_ok(account, contact, file_props):
-
-            def on_ok(widget, account, contact, file_props):
-                file_path = dialog2.get_filename()
-                file_path = gtkgui_helpers.decode_filechooser_file_paths(
-                        (file_path,))[0]
-                if os.path.exists(file_path):
-                    # check if we have write permissions
-                    if not os.access(file_path, os.W_OK):
-                        file_name = os.path.basename(file_path)
-                        dialogs.ErrorDialog(_('Cannot overwrite existing file "%s"' % file_name),
-                        _('A file with this name already exists and you do not have permission to overwrite it.'))
-                        return
-                    stat = os.stat(file_path)
-                    dl_size = stat.st_size
-                    file_size = file_props['size']
-                    dl_finished = dl_size >= file_size
-
-                    def on_response(response):
-                        if response < 0:
-                            return
-                        elif response == 100:
-                            file_props['offset'] = dl_size
-                        dialog2.destroy()
-                        self._start_receive(file_path, account, contact, file_props)
-
-                    dialog = dialogs.FTOverwriteConfirmationDialog(
-                            _('This file already exists'), _('What do you want to do?'),
-                            propose_resume=not dl_finished, on_response=on_response)
-                    dialog.set_transient_for(dialog2)
-                    dialog.set_destroy_with_parent(True)
-                    return
-                else:
-                    dirname = os.path.dirname(file_path)
-                    if not os.access(dirname, os.W_OK) and os.name != 'nt':
-                        # read-only bit is used to mark special folder under windows,
-                        # not to mark that a folder is read-only. See ticket #3587
-                        dialogs.ErrorDialog(_('Directory "%s" is not writable') % dirname, _('You do not have permission to create files in this directory.'))
-                        return
-                dialog2.destroy()
-                self._start_receive(file_path, account, contact, file_props)
-
-            def on_cancel(widget, account, contact, file_props):
-                dialog2.destroy()
-                gajim.connections[account].send_file_rejection(file_props)
-
-            dialog2 = dialogs.FileChooserDialog(
-                    title_text=_('Save File as...'),
-                    action=gtk.FILE_CHOOSER_ACTION_SAVE,
-                    buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                    gtk.STOCK_SAVE, gtk.RESPONSE_OK),
-                    default_response=gtk.RESPONSE_OK,
-                    current_folder=gajim.config.get('last_save_dir'),
-                    on_response_ok=(on_ok, account, contact, file_props),
-                    on_response_cancel=(on_cancel, account, contact, file_props))
-
-            dialog2.set_current_name(file_props['name'])
-            dialog2.connect('delete-event', lambda widget, event:
-                    on_cancel(widget, account, contact, file_props))
+            self.on_file_request_accepted(account, contact, file_props)
 
         def on_response_cancel(account, file_props):
             gajim.connections[account].send_file_rejection(file_props)
@@ -573,7 +593,7 @@ class FileTransfersWindow:
             iter_ = self.model.iter_next(iter_)
 
     def get_send_file_props(self, account, contact, file_path, file_name,
-                    file_desc=''):
+    file_desc=''):
         """
         Create new file_props dict and set initial file transfer properties in it
         """
@@ -801,13 +821,14 @@ class FileTransfersWindow:
         s_iter = selected[1]
         sid = self.model[s_iter][C_SID].decode('utf-8')
         file_props = self.files_props[sid[0]][sid[1:]]
-        if self.is_transfer_paused(file_props):
+        if is_transfer_paused(file_props):
             file_props['last-time'] = time.time()
             file_props['paused'] = False
             types = {'r' : 'download', 's' : 'upload'}
             self.set_status(file_props['type'], file_props['sid'], types[sid[0]])
             self.toggle_pause_continue(True)
-            file_props['continue_cb']()
+            if file_props['continue_cb']:
+                file_props['continue_cb']()
         elif is_transfer_active(file_props):
             file_props['paused'] = True
             self.set_status(file_props['type'], file_props['sid'], 'pause')
