@@ -4,7 +4,7 @@
 ## Copyright (C) 2005 Sebastian Estienne
 ## Copyright (C) 2005-2006 Andrew Sayman <lorien420 AT myrealbox.com>
 ## Copyright (C) 2005-2007 Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2010 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2005-2012 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2006 Travis Shirk <travis AT pobox.com>
 ## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
 ## Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
@@ -29,13 +29,14 @@
 
 import os
 import time
-import dialogs
+from dialogs import PopupNotificationWindow
 import gobject
 import gtkgui_helpers
 import gtk
 
 from common import gajim
 from common import helpers
+from common import ged
 
 from common import dbus_support
 if dbus_support.supported:
@@ -56,12 +57,6 @@ def get_show_in_roster(event, account, contact, session=None):
     """
     if event == 'gc_message_received':
         return True
-    num = get_advanced_notification(event, account, contact)
-    if num is not None:
-        if gajim.config.get_per('notifications', str(num), 'roster') == 'yes':
-            return True
-        if gajim.config.get_per('notifications', str(num), 'roster') == 'no':
-            return False
     if event == 'message_received':
         if session and session.control:
             return False
@@ -71,252 +66,12 @@ def get_show_in_systray(event, account, contact, type_=None):
     """
     Return True if this event must be shown in systray, else False
     """
-    num = get_advanced_notification(event, account, contact)
-    if num is not None:
-        if gajim.config.get_per('notifications', str(num), 'systray') == 'yes':
-            return True
-        if gajim.config.get_per('notifications', str(num), 'systray') == 'no':
-            return False
     if type_ == 'printed_gc_msg' and not gajim.config.get(
     'notify_on_all_muc_messages'):
         # it's not an highlighted message, don't show in systray
         return False
     return gajim.config.get('trayicon_notification_on_events')
 
-def get_advanced_notification(event, account, contact):
-    """
-    Returns the number of the first (top most) advanced notification else None
-    """
-    num = 0
-    notif = gajim.config.get_per('notifications', str(num))
-    while notif:
-        recipient_ok = False
-        status_ok = False
-        tab_opened_ok = False
-        # test event
-        if gajim.config.get_per('notifications', str(num), 'event') == event:
-            # test recipient
-            recipient_type = gajim.config.get_per('notifications', str(num),
-                'recipient_type')
-            recipients = gajim.config.get_per('notifications', str(num),
-                'recipients').split()
-            if recipient_type == 'all':
-                recipient_ok = True
-            elif recipient_type == 'contact' and contact.jid in recipients:
-                recipient_ok = True
-            elif recipient_type == 'group':
-                for group in contact.groups:
-                    if group in contact.groups:
-                        recipient_ok = True
-                        break
-        if recipient_ok:
-            # test status
-            our_status = gajim.SHOW_LIST[gajim.connections[account].connected]
-            status = gajim.config.get_per('notifications', str(num), 'status')
-            if status == 'all' or our_status in status.split():
-                status_ok = True
-        if status_ok:
-            # test window_opened
-            tab_opened = gajim.config.get_per('notifications', str(num),
-                'tab_opened')
-            if tab_opened == 'both':
-                tab_opened_ok = True
-            else:
-                chat_control = helpers.get_chat_control(account, contact)
-                if (chat_control and tab_opened == 'yes') or (not chat_control \
-                and tab_opened == 'no'):
-                    tab_opened_ok = True
-        if tab_opened_ok:
-            return num
-
-        num += 1
-        notif = gajim.config.get_per('notifications', str(num))
-
-def notify(event, jid, account, parameters, advanced_notif_num=None):
-    """
-    Check what type of notifications we want, depending on basic and the
-    advanced configuration of notifications and do these notifications;
-    advanced_notif_num holds the number of the first (top most) advanced
-    notification
-    """
-    # First, find what notifications we want
-    do_popup = False
-    do_sound = False
-    do_cmd = False
-    if event == 'status_change':
-        new_show = parameters[0]
-        status_message = parameters[1]
-        # Default: No popup for status change
-    elif event == 'contact_connected':
-        status_message = parameters
-        j = gajim.get_jid_without_resource(jid)
-        server = gajim.get_server_from_jid(j)
-        account_server = account + '/' + server
-        block_transport = False
-        if account_server in gajim.block_signed_in_notifications and \
-        gajim.block_signed_in_notifications[account_server]:
-            block_transport = True
-        if helpers.allow_showing_notification(account, 'notify_on_signin') and \
-        not gajim.block_signed_in_notifications[account] and \
-        not block_transport:
-            do_popup = True
-        if gajim.config.get_per('soundevents', 'contact_connected',
-        'enabled') and not gajim.block_signed_in_notifications[account] and \
-        not block_transport and helpers.allow_sound_notification(account,
-        event, advanced_notif_num):
-            do_sound = True
-    elif event == 'contact_disconnected':
-        status_message = parameters
-        if helpers.allow_showing_notification(account, 'notify_on_signout'):
-            do_popup = True
-        if gajim.config.get_per('soundevents', 'contact_disconnected',
-        'enabled') and helpers.allow_sound_notification(account,
-        event, advanced_notif_num):
-            do_sound = True
-    elif event == 'new_message':
-        message_type = parameters[0]
-        is_first_message = parameters[1]
-        nickname = parameters[2]
-        if gajim.config.get('notification_preview_message'):
-            message = parameters[3]
-            if message.startswith('/me ') or message.startswith('/me\n'):
-                message = '* ' + nickname + message[3:]
-        else:
-            # We don't want message preview, do_preview = False
-            message = ''
-        focused = parameters[4]
-        if helpers.allow_showing_notification(account, 'notify_on_new_message',
-        advanced_notif_num, is_first_message):
-            do_popup = True
-        if is_first_message and helpers.allow_sound_notification(account,
-        'first_message_received', advanced_notif_num):
-            do_sound = True
-        elif not is_first_message and focused and \
-        helpers.allow_sound_notification(account,
-        'next_message_received_focused', advanced_notif_num):
-            do_sound = True
-        elif not is_first_message and not focused and \
-        helpers.allow_sound_notification(account,
-        'next_message_received_unfocused', advanced_notif_num):
-            do_sound = True
-    else:
-        print '*Event not implemeted yet*'
-
-    if advanced_notif_num is not None and gajim.config.get_per('notifications',
-    str(advanced_notif_num), 'run_command'):
-        do_cmd = True
-
-    # Do the wanted notifications
-    if do_popup:
-        if event in ('contact_connected', 'contact_disconnected',
-        'status_change'): # Common code for popup for these three events
-            if event == 'contact_disconnected':
-                show_image = 'offline.png'
-                suffix = '_notif_size_bw'
-            else: # Status Change or Connected
-                # FIXME: for status change,
-                # we don't always 'online.png', but we
-                # first need 48x48 for all status
-                show_image = 'online.png'
-                suffix = '_notif_size_colored'
-            transport_name = gajim.get_transport_name_from_jid(jid)
-            img_path = None
-            if transport_name:
-                img_path = os.path.join(helpers.get_transport_path(
-                    transport_name), '48x48', show_image)
-            if not img_path or not os.path.isfile(img_path):
-                iconset = gajim.config.get('iconset')
-                img_path = os.path.join(helpers.get_iconset_path(iconset),
-                    '48x48', show_image)
-            path = gtkgui_helpers.get_path_to_generic_or_avatar(img_path,
-                jid=jid, suffix=suffix)
-            if event == 'status_change':
-                title = _('%(nick)s Changed Status') % \
-                    {'nick': gajim.get_name_from_jid(account, jid)}
-                text = _('%(nick)s is now %(status)s') % \
-                    {'nick': gajim.get_name_from_jid(account, jid),\
-                    'status': helpers.get_uf_show(gajim.SHOW_LIST[new_show])}
-                if status_message:
-                    text = text + " : " + status_message
-                popup(_('Contact Changed Status'), jid, account,
-                    path_to_image=path, title=title, text=text)
-            elif event == 'contact_connected':
-                title = _('%(nickname)s Signed In') % \
-                    {'nickname': gajim.get_name_from_jid(account, jid)}
-                text = ''
-                if status_message:
-                    text = status_message
-                popup(_('Contact Signed In'), jid, account,
-                    path_to_image=path, title=title, text=text)
-            elif event == 'contact_disconnected':
-                title = _('%(nickname)s Signed Out') % \
-                    {'nickname': gajim.get_name_from_jid(account, jid)}
-                text = ''
-                if status_message:
-                    text = status_message
-                popup(_('Contact Signed Out'), jid, account,
-                    path_to_image=path, title=title, text=text)
-        elif event == 'new_message':
-            if message_type == 'normal': # single message
-                event_type = _('New Single Message')
-                img_name = 'gajim-single_msg_recv'
-                title = _('New Single Message from %(nickname)s') % \
-                    {'nickname': nickname}
-                text = message
-            elif message_type == 'pm': # private message
-                event_type = _('New Private Message')
-                room_name = gajim.get_nick_from_jid(jid)
-                img_name = 'gajim-priv_msg_recv'
-                title = _('New Private Message from group chat %s') % room_name
-                if message:
-                    text = _('%(nickname)s: %(message)s') % \
-                        {'nickname': nickname, 'message': message}
-                else:
-                    text = _('Messaged by %(nickname)s') % \
-                        {'nickname': nickname}
-
-            else: # chat message
-                event_type = _('New Message')
-                img_name = 'gajim-chat_msg_recv'
-                title = _('New Message from %(nickname)s') % \
-                    {'nickname': nickname}
-                text = message
-            img_path = gtkgui_helpers.get_icon_path(img_name, 48)
-            popup(event_type, jid, account, message_type,
-                path_to_image=img_path, title=title, text=text)
-
-    if do_sound:
-        snd_file = None
-        snd_event = None # If not snd_file, play the event
-        if event == 'new_message':
-            if advanced_notif_num is not None and gajim.config.get_per(
-            'notifications', str(advanced_notif_num), 'sound') == 'yes':
-                snd_file = gajim.config.get_per('notifications',
-                    str(advanced_notif_num), 'sound_file')
-            elif advanced_notif_num is not None and gajim.config.get_per(
-            'notifications', str(advanced_notif_num), 'sound') == 'no':
-                pass # do not set snd_event
-            elif is_first_message:
-                snd_event = 'first_message_received'
-            elif focused:
-                snd_event = 'next_message_received_focused'
-            else:
-                snd_event = 'next_message_received_unfocused'
-        elif event in ('contact_connected', 'contact_disconnected'):
-            snd_event = event
-        if snd_file:
-            helpers.play_sound_file(snd_file)
-        if snd_event:
-            helpers.play_sound(snd_event)
-
-    if do_cmd:
-        command = gajim.config.get_per('notifications', str(advanced_notif_num),
-            'command')
-        try:
-            helpers.exec_command(command)
-        except Exception:
-            pass
-
 def popup(event_type, jid, account, msg_type='', path_to_image=None, title=None,
 text=None):
     """
@@ -378,8 +133,8 @@ text=None):
             gajim.log.debug(str(e))
 
     # Either nothing succeeded or the user wants old-style notifications
-    instance = dialogs.PopupNotificationWindow(event_type, jid, account,
-        msg_type, path_to_image, title, text)
+    instance = PopupNotificationWindow(event_type, jid, account, msg_type,
+        path_to_image, title, text)
     gajim.interface.roster.popup_notification_windows.append(instance)
 
 def on_pynotify_notification_clicked(notification, action):
@@ -390,6 +145,32 @@ def on_pynotify_notification_clicked(notification, action):
     notification.close()
     gajim.interface.handle_event(account, jid, msg_type)
 
+class Notification:
+    """
+    Handle notifications
+    """
+    def __init__(self):
+        gajim.ged.register_event_handler('notification', ged.GUI2,
+            self._nec_notification)
+
+    def _nec_notification(self, obj):
+        if obj.do_popup:
+            popup(obj.popup_event_type, obj.jid, obj.conn.name,
+                obj.popup_msg_type, path_to_image=obj.popup_image,
+                title=obj.popup_title, text=obj.popup_text)
+
+        if obj.do_sound:
+            if obj.sound_file:
+                helpers.play_sound_file(obj.sound_file)
+            elif obj.sound_event:
+                helpers.play_sound(obj.sound_event)
+
+        if obj.do_command:
+            try:
+                helpers.exec_command(obj.command, use_shell=True)
+            except Exception:
+                pass
+
 class NotificationResponseManager:
     """
     Collect references to pending DesktopNotifications and manages there
@@ -411,11 +192,14 @@ class NotificationResponseManager:
         self.interface.connect_to_signal('NotificationClosed', self.on_closed)
 
     def on_action_invoked(self, id_, reason):
-        self.received.append((id_, time.time(), reason))
         if id_ in self.pending:
             notification = self.pending[id_]
             notification.on_action_invoked(id_, reason)
             del self.pending[id_]
+            return
+        # got an action on popup that isn't handled yet? Maybe user clicked too
+        # fast. Remember it.
+        self.received.append((id_, time.time(), reason))
         if len(self.received) > 20:
             curt = time.time()
             for rec in self.received:
@@ -452,7 +236,7 @@ class DesktopNotification:
 
     def __init__(self, event_type, jid, account, msg_type='',
     path_to_image=None, title=None, text=None):
-        self.path_to_image = path_to_image
+        self.path_to_image = os.path.abspath(path_to_image)
         self.event_type = event_type
         self.title = title
         self.text = text
@@ -583,10 +367,11 @@ class DesktopNotification:
                 # it seems notification-daemon doesn't like empty text
                 if self.text:
                     text = self.text
+                    if len(self.text) > 200:
+                        text = '%s\n...' % self.text[:200]
                 else:
                     text = ' '
                 if os.environ.get('KDE_FULL_SESSION') == 'true':
-                    self.path_to_image = os.path.abspath(self.path_to_image)
                     text = '<table style=\'padding: 3px\'><tr><td>' \
                         '<img src=\"%s\"></td><td width=20> </td>' \
                         '<td>%s</td></tr></table>' % (self.path_to_image,
@@ -629,14 +414,13 @@ class DesktopNotification:
                     self.notify_another_way(e)
 
     def attach_by_id(self, id_):
-        self.id = id_
         notification_response_manager.attach_to_interface()
-        notification_response_manager.add_pending(self.id, self)
+        notification_response_manager.add_pending(id_, self)
 
     def notify_another_way(self, e):
         gajim.log.debug('Error when trying to use notification daemon: %s' % \
             str(e))
-        instance = dialogs.PopupNotificationWindow(self.event_type, self.jid,
+        instance = PopupNotificationWindow(self.event_type, self.jid,
             self.account, self.msg_type, self.path_to_image, self.title,
             self.text)
         gajim.interface.roster.popup_notification_windows.append(instance)
